# -*- coding: utf-8 -*-

from openerp import models, fields, api

class AccountInvoice(models.Model):
	_inherit = 'account.invoice'

	############################################################
	#	ACCOUNT INVOICE
	############################################################

	@api.model
	def getAccountInvoice(self,domain):
		AccountInvoice = self.env['account.invoice'].search(domain)
		decimal_precision = self.env['decimal.precision'].precision_get('Account')
		values = []
		for invoice in AccountInvoice:
			values.append({
				'id': invoice.id,
				'type': invoice.type,
				'state': invoice.state,
				'number': invoice.number,
				'journal_id': [
					invoice.journal_id.id,
					invoice.journal_id.name
				],
				'invoice_currency': [
					invoice.currency_id.id,
					invoice.currency_id.name,
					invoice.currency_id.rate
				],
				'company_currency': [
					invoice.company_id.currency_id.id,
					invoice.company_id.currency_id.name,
					invoice.company_id.currency_id.rate
				],
				'date_invoice': invoice.date_invoice,
				'partner_id': [
					invoice.partner_id.id,
					invoice.partner_id.name,
					invoice.partner_id.ruc,
				],
				'supplier_invoice_number': invoice.supplier_invoice_number,
				'user_id': [
					invoice.user_id.id,
					invoice.user_id.name
				],
                'period_id': [
                	invoice.period_id.id,
                	invoice.period_id.name
                ],
                'amount_untaxed': invoice.amount_untaxed,
                'residual': invoice.residual,
                'amount_tax': invoice.amount_tax,
				'amount_total': invoice.amount_total,
				'amount_untaxed_currency': invoice.amount_untaxed * (invoice.company_id.currency_id.rate / invoice.currency_id.rate),
				'residual_currency': invoice.residual * (invoice.company_id.currency_id.rate / invoice.currency_id.rate),
				'amount_tax_currency': invoice.amount_tax * (invoice.company_id.currency_id.rate / invoice.currency_id.rate),
				'amount_total_currency': invoice.amount_total * (invoice.company_id.currency_id.rate / invoice.currency_id.rate),
			})

		return values

	############################################################
	#	POS ORDER
	############################################################

	@api.model
	def getPosOrder(self,domain):
		PosOrder = self.env['pos.order'].search(domain)
		decimal_precision = self.env['decimal.precision'].precision_get('Account')
		values = []
		for order in PosOrder:
			values.append({
				'id': order.id,
				'name': order.name,
				'date_order': order.date_order,
				'pricelist_id':[
					order.pricelist_id.id,
					order.pricelist_id.name,
				],
				'partner_id': [
					order.partner_id.id,
					order.partner_id.name,
					order.partner_id.ruc,
				],
				'user_id': [
					order.user_id.id,
					order.user_id.name
				],
				'order_currency': [
					order.pricelist_id.currency_id.id,
					order.pricelist_id.currency_id.name,
					order.pricelist_id.currency_id.rate
				],
				'company_currency': [
					order.company_id.currency_id.id,
					order.company_id.currency_id.name,
					order.company_id.currency_id.rate
				],
                'amount_tax': order.amount_tax,
                'amount_total': order.amount_total,
				'amount_tax_currency': order.amount_tax * (order.company_id.currency_id.rate / order.pricelist_id.currency_id.rate),
				'amount_total_currency': order.amount_total * (order.company_id.currency_id.rate / order.pricelist_id.currency_id.rate),
			})

		return values

class AccountInvoiceLine(models.Model):
	_inherit = 'account.invoice.line'

	############################################################
	#	ACCOUNT INVOICE LINE
	############################################################

	@api.model
	def getAccountInvoiceLine(self,domain):
		AccountInvoiceLine = self.env['account.invoice.line'].search(domain)
		decimal_precision = self.env['decimal.precision'].precision_get('Account')
		values = []
		for line in AccountInvoiceLine:
			values.append({
				'id': line.id,
				'invoice_id':line.invoice_id.id,
				'number':line.invoice_id.number,
				'supplier_invoice_number':line.invoice_id.supplier_invoice_number,
				'date_invoice': line.invoice_id.date_invoice,
				'user_id': [
					line.invoice_id.user_id.id,
					line.invoice_id.user_id.name,
				],
				'partner_id': [
					line.invoice_id.partner_id.id,
					line.invoice_id.partner_id.name,
				],
				'product_id': [
					line.product_id.id,
					line.product_id.display_name,
					line.product_id.categ_id.complete_name,
				],
				'price_unit': line.price_unit,
				'price_subtotal': line.price_subtotal,
				'quantity': line.quantity,
				'company_currency':[
					line.invoice_id.company_id.currency_id.id,
					line.invoice_id.company_id.currency_id.name,
					line.invoice_id.company_id.currency_id.rate,
				],
				'invoice_currency':[
					line.invoice_id.currency_id.id,
					line.invoice_id.currency_id.name,
					line.invoice_id.currency_id.rate,
				],
				'price_unit_currency': round(line.price_unit * (line.invoice_id.company_id.currency_id.rate / line.invoice_id.currency_id.rate),decimal_precision),
				'price_subtotal_currency': round(line.price_subtotal * (line.invoice_id.company_id.currency_id.rate / line.invoice_id.currency_id.rate),decimal_precision),
				'tax_currency': round((line.price_unit * (line.invoice_id.company_id.currency_id.rate / line.invoice_id.currency_id.rate) * line.quantity) - line.price_subtotal * (line.invoice_id.company_id.currency_id.rate / line.invoice_id.currency_id.rate),decimal_precision),
				'amount_currency': round((line.quantity * line.price_unit) * (line.invoice_id.company_id.currency_id.rate / line.invoice_id.currency_id.rate),decimal_precision),
			})

		return values

	############################################################
	#	POS ORDER LINE
	############################################################

	@api.model
	def getPosOrderLine(self,domain):
		PosOrderLine = self.env['pos.order.line'].search(domain)
		decimal_precision = self.env['decimal.precision'].precision_get('Account')
		values = []
		for line in PosOrderLine:
			values.append({
				'id': line.id,
				'order_id': [
					line.order_id.id,
					line.order_id.name
				],
				'product_id': [
					line.product_id.id,
					line.product_id.display_name,
				],
				'qty': line.qty,
				'create_date': line.create_date,
				'user_id': [
					line.order_id.user_id.id,
					line.order_id.user_id.name
				],
				'partner_id': [
					line.order_id.partner_id.id,
					line.order_id.partner_id.name
				],
				'company_currency':[
					line.order_id.company_id.currency_id.id,
					line.order_id.company_id.currency_id.name,
					line.order_id.company_id.currency_id.rate,
				],
				'order_currency':[
					line.order_id.pricelist_id.currency_id.id,
					line.order_id.pricelist_id.currency_id.name,
					line.order_id.pricelist_id.currency_id.rate,
				],
				'price_unit': line.price_unit,
				'price_subtotal': line.price_subtotal,
				'price_subtotal_incl': line.price_subtotal_incl,
				'price_unit_currency': round(line.price_unit * (line.order_id.company_id.currency_id.rate / line.order_id.pricelist_id.currency_id.rate),decimal_precision),
				'price_subtotal_currency': round(line.price_subtotal * (line.order_id.company_id.currency_id.rate / line.order_id.pricelist_id.currency_id.rate),decimal_precision),
				'price_subtotal_incl_currency': round(line.price_subtotal_incl * (line.order_id.company_id.currency_id.rate / line.order_id.pricelist_id.currency_id.rate),decimal_precision),
				# 'amount_currency': round(line.price_subtotal_incl * (line.order_id.company_id.currency_id.rate / line.order_id.pricelist_id.currency_id.rate),decimal_precision)
			})

		return values

class AccountJournal(models.Model):
	_inherit = 'account.journal'

	@api.model
	def getAccountJournal(self,domain):
		AccountJournal = self.env['account.journal'].search(domain)
		values = []
		for journal in AccountJournal:
			values.append({
				'id': journal.id,
				'name': journal.name,
				'store_ids': [
					journal.store_ids.id,
				],
				'company_id': [
					journal.company_id.id,
					journal.company_id.name
				],
			})

		return values

class ResCompany(models.Model):
	_inherit = 'res.company'

	@api.model
	def getResCompany(self,domain):
		ResCompany = self.env['res.company'].search(domain)
		values = []
		for company in ResCompany:
			values.append({
				'id': company.id,
				'name': company.name,
				'currency_id': [
					company.currency_id.id,
					company.currency_id.name,
				],
				'company_ruc': company.partner_id.ruc,
				'phone': company.phone,
				'logo': company.logo,
			})

		return values

class ResCurrency(models.Model):
	_inherit = 'res.currency'

	@api.model
	def getResCurrency(self,domain):
		ResCurrency = self.env['res.currency'].search(domain)
		values = []
		for currency in ResCurrency:
			values.append({
				'id': currency.id,
				'name': currency.name,
				'symbol': currency.symbol,
				'rate_silent': currency.rate_silent,
				'base': currency.base,
				'decimal_separator': currency.decimal_separator,
				'decimal_places': currency.decimal_places,
				'thousands_separator': currency.thousands_separator,
				'symbol_position': currency.symbol_position,
			})

		return values

class ResPartner(models.Model):
	_inherit = 'res.partner'

	@api.model
	def getResPartnerMedic(self,domain):
		ResPartner = self.env['res.partner'].search(domain)
		values = []
		for partner in ResPartner:
			values.append({
				'id': partner.id,
				'name': partner.name,
				'ruc': partner.ruc,
				'street': partner.street,
				'city': partner.city,
				'phone': partner.phone,
				'mobile': partner.mobile,
				'email': partner.email,
				'property_product_pricelist': partner.property_product_pricelist.name,
				'property_product_pricelist_purchase': partner.property_product_pricelist_purchase.name,
				'credit': partner.credit,
				'debit': partner.debit,
				'supplier': partner.supplier,
				'is_medic': partner.is_medic,
				'medic': [
					partner.medic.id,
					partner.medic.name,
				],
			})

		return values

class ProductProduct(models.Model):
	_inherit = 'product.product'

	############################################################
	#	PRODUCT PRODUCT
	############################################################

	@api.model
	def getProductProduct(self,domain):
		ProductProduct = self.env['product.product'].search(domain)
		values = []
		for product in ProductProduct:
			attributeValuesLines = map(lambda x: x.id, product.attribute_value_ids)
			attributeIDS = []
			for arttIds in self.env['product.attribute.value'].search([('id', 'in', attributeValuesLines)]):
				attributeIDS.append(arttIds.attribute_id.id)

			try:
				brand = product.product_brand_id.id
			except:
				brand = ''

			values.append({
				'id': product.id,
				'name': product.name,
				'display_name': product.display_name,
				'standard_price': product.standard_price,
				'lst_price': product.lst_price,
				'categ_id': {
					'id': product.categ_id.id,
					'name': product.categ_id.name,
					'complete_name': product.categ_id.complete_name,
				},
				'product_brand_id': brand,
				'atribute_value_ids': attributeValuesLines,
				'attribute_ids': attributeIDS
			})

		return values

	############################################################
	#	PRODUCT BRAND
	############################################################

	@api.model
	def getProductBrand(self,domain):
		ProductBrand = self.env['product.brand'].search(domain)
		values = []
		for brand in ProductBrand:
			values.append({
				'id': brand.id,
				'name': brand.name,
			})

		return values

class ProductCategory(models.Model):
	_inherit = 'product.category'

	@api.model
	def getProductCategory(self,domain):
		ProductCategory = self.env['product.category'].search(domain)
		values = []
		for category in ProductCategory:
			values.append({
				'id': category.id,
				'name': category.name,
				'display_name': category.display_name,
				'parent_id': [
					category.parent_id.id,
					category.parent_id.name,
				],
			})

		return values

class ProductAttribute(models.Model):
	_inherit = 'product.attribute'

	@api.model
	def getProductAttribute(self,domain):
		ProductAttribute = self.env['product.attribute'].search(domain)
		values = []
		for attribute in ProductAttribute:
			values.append({
				'id': attribute.id,
				'name': attribute.name,
			})

		return values

class ProductAttributeValue(models.Model):
	_inherit = 'product.attribute.value'

	@api.model
	def getProductAttributeValue(self,domain):
		ProductAttributeValue = self.env['product.attribute.value'].search(domain)
		values = []
		for value in ProductAttributeValue:
			values.append({
				'id': value.id,
				'name': value.name,
				'attribute_id': [
					value.attribute_id.id,
					value.attribute_id.name,
				],
			})

		return values

class StockLocation(models.Model):
	_inherit = 'stock.location'

	@api.model
	def getStockLocation(self,domain):
		StockLocation = self.env['stock.location'].search(domain)
		values = []
		for location in StockLocation:
			values.append({
				'id': location.id,
				'name': location.name,
				'display_name': location.display_name,
				'company_id': [
					location.company_id.id,
					location.company_id.name,
				],
				'store_id': [
					location.store_id.id,
					location.store_id.name,
				],
				'usage': location.usage,
			})

		return values

class StockQuant(models.Model):
	_inherit = 'stock.quant'

	@api.model
	def getStockQuant(self,domain):
		StockQuant = self.env['stock.quant'].search(domain)
		values = []
		for quant in StockQuant:
			values.append({
				'id': quant.id,
				'name': quant.name,
				'display_name': quant.display_name,
				'location_id': [
					quant.location_id.id,
					quant.location_id.name,
				],
				'product_id': [
					quant.product_id.id,
					quant.product_id.name,
				],
				'qty': quant.qty,
			})

		return values
